package Locale::CLDR::Locales::En::Any;

# This file auto generated
#	on Sun 16 Dec  4:13:26 pm GMT

use version;

our $VERSION = version->declare('v0.34.0');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::En');

no Moo;

1;
